﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Windows.Media.Animation;

namespace TestXamDataGrid
{
    /// <summary>
    /// Interaction logic for LoadingStatusScreen.xaml
    /// </summary>
    public partial class LoadingStatusScreen : Window
    {
        public delegate void UpdateMyStatus(int Percentage, String Message);
        Storyboard StatusStoryBoard;

        public LoadingStatusScreen(int Percentage, string Message)
        {
            InitializeComponent();
            UpdateStatus(Percentage, Message);
        }

        public void UpdateStatus(string Message)
        {
            UpdateStatus(Convert.ToInt16(StatusProgressBar.Value), Message);
        }

        public void UpdateStatus(int Percentage)
        {
            UpdateStatus(Percentage, StatusTextBlock.Text);
        }

        public void UpdateStatus(int Percentage, string Message)
        {
            if (this.Dispatcher.Thread != System.Threading.Thread.CurrentThread)
            {
                return;
            }
            StatusTextBlock.Text = Message;
            if (Percentage > 100) Percentage = 100;
            if (Percentage < 0) Percentage = 0;

            if (StatusStoryBoard != null)
            {
                if (StatusStoryBoard.GetCurrentProgress(this) != null) StatusStoryBoard.SkipToFill();
            }
            else StatusStoryBoard = new Storyboard();
            StatusStoryBoard.Children.Clear();
            // Create a storyboard to contain the animations.

            TimeSpan duration = new TimeSpan(0, 0, 0, 0, 750);

            DoubleAnimation animation = new DoubleAnimation();

            animation.From = StatusProgressBar.Value;
            animation.To = Percentage;
            animation.Duration = new Duration(duration);
            Storyboard.SetTargetName(animation, StatusProgressBar.Name);
            Storyboard.SetTargetProperty(animation, new PropertyPath(ProgressBar.ValueProperty));
            StatusStoryBoard.Children.Add(animation);

            if (Percentage == 100) StatusStoryBoard.Completed += new EventHandler(RunCloseWindowStoryBoard);

            // Begin the storyboard
            StatusStoryBoard.Begin(this, true);
        }

        public void CloseWindow(string Message)
        {
            if (StatusProgressBar.Value < 100) UpdateStatus(100, Message);
        }

        void RunCloseWindowStoryBoard(object sender, EventArgs e)
        {
            // Create a storyboard to contain the animations.
            Storyboard storyboard = new Storyboard();
            TimeSpan duration = new TimeSpan(0, 0, 0, 0, 500);

            DoubleAnimation animation = new DoubleAnimation();

            animation.From = 1;
            animation.To = 0;
            animation.Duration = new Duration(duration);
            Storyboard.SetTarget(animation, this);
            Storyboard.SetTargetProperty(animation, new PropertyPath(Window.OpacityProperty));
            // Add the animation to the storyboard
            storyboard.Children.Add(animation);

            storyboard.Completed += new EventHandler(storyboard_Completed);
            // Begin the storyboard
            storyboard.Begin(this);
        }

        void storyboard_Completed(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}
